Multiple pde example / pipe model
---------------------------------

.. autoapimodule:: pyinduct.examples.pipe_flow


.. literalinclude:: /../pyinduct/examples/pipe_flow.py
    :language: python
    :start-after: # (sphinx directive) start actual script
